@@ -1,7 +1,7 @@
-from luna.lunaUtils import LunaUtils
+from luna.baseLunaUtils import BaseLunaUtils
 import os
 
-class LocalLunaUtils(LunaUtils):
+class LocalLunaUtils(BaseLunaUtils):
     def RegisterModel(self, model_path, description, luna_python_model=None):
         # do nothing
         return
