@@ -7,6 +7,9 @@ import yaml
 import io
 import argparse
 import json
+import os
+
+MLFLOW_MODEL_PATH = "MLFLOW_MODELS"
 
 class LunaUtils(object):
     
@@ -61,4 +64,11 @@ class LunaUtils(object):
 
         args = parser.parse_args()
         userInput = json.loads(args.userInput)
-        return args, userInput
\ No newline at end of file
+        return args, userInput
+
+    @staticmethod
+    def GetModelPath(run_type, context):
+        if run_type == 'azureml':
+            return os.getenv('AZUREML_MODEL_DIR')
+        else:
+            return context[MLFLOW_MODEL_PATH]
\ No newline at end of file
