@@ -46,6 +46,7 @@ def RegisterModel(model_path, description, args):
         mlFlowRun = mlflow.active_run()
         print(mlFlowRun)
         if mlFlowRun:
+            mlflow.log_artifacts(model_path, model_path)
             model_uri = "runs:/{run_id}/{artifact_path}".format(run_id=mlFlowRun.info.run_id, artifact_path=model_path)
             print(model_uri)
             result = mlflow.register_model(
@@ -70,6 +71,7 @@ def GetModelPath():
 def ParseArguments(run_type):
     parser = argparse.ArgumentParser(run_type)
 
+    parser.add_argument("--runMode", type=str, help="run mode, support azureML or MLflow")
     parser.add_argument("--userInput", type=str, help="input data")
     parser.add_argument("--modelId", type=str, help="model key")
 
